@@ -45,11 +45,6 @@ def attention(
 
 # memory efficient attention
 
-def safe_sum(acc, el):
-    if not exists(acc):
-        return el
-    return acc + el
-
 def summarize_qkv_chunk(q, k, v, mask, causal_mask):
     weight = einsum('b h i d, b h j d -> b h i j', q, k)
     weight_max = weight.amax(dim = -1, keepdim = True).detach()
@@ -156,7 +151,6 @@ class Attention(nn.Module):
         super().__init__()
         self.heads = heads
         self.causal = causal
-        self.scale = dim_head ** -0.5
 
         inner_dim = heads * dim_head
 
@@ -189,8 +183,6 @@ class Attention(nn.Module):
         q = self.to_q(x)
         k, v = self.to_kv(context).chunk(2, dim = -1)
 
-        q = q * self.scale
-
         q, k, v = map(lambda t: rearrange(t, 'b n (h d) -> b h n d', h = h), (q, k, v))
 
         attn_fn = attention if not memory_efficient else memory_efficient_attention
